@@ -92,7 +92,7 @@ class DefaultSettings():
             self._ARMSimDirectory = ""
         self._ARMSimServer = "localhost"
         self._ARMSimPort = 8010
-        gcc_names = ["arm-none-eabi-gcc", "arm-unknown-linux-gnueabi-gcc"]
+        gcc_names = ["arm-none-eabi-gcc", "arm-unknown-linux-gnueabi-gcc", "arm-linux-gnueabi-gcc"]
         if sys.platform == "win32":
             gcc_names = ["{}.exe".format(name) for name in gcc_names]
         fname = ""
@@ -882,12 +882,12 @@ class QtARMSimMainWindow(QtGui.QMainWindow):
             and not self.settings.value("ARMSimCommand"):
             QtGui.QMessageBox.warning(self, self.tr("ARMSim command empty"),
                     self.tr("ARMSim command is empty.\n\n"
-                            "Please go to 'View, Preferences...' and set it.\n"))
+                            "Please go to 'Edit, Preferences...' and set it.\n"))
             return False
         if not os.path.isfile(self.settings.value("ARMGccCommand")):
             QtGui.QMessageBox.warning(self, self.tr("ARM gcc not found"),
                     self.tr("ARM gcc command not found.\n\n"
-                            "Please go to 'View, Preferences...' and set it.\n"))
+                            "Please go to 'Edit, Preferences...' and set it.\n"))
             return False
         self.simulator = ARMSimConnector(verbose = self.verbose)
         self.statusBar().showMessage(self.tr("Connecting to ARMSim..."), 2000)
